
# Type: string


A character string

URI: [https://w3id.org/biolink/vocab/biolinkml:types/String](https://w3id.org/biolink/vocab/biolinkml:types/String)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **str** |
